@@ -37,7 +37,6 @@ import (
 	"github.com/MakeNowJust/heredoc/v2"
 	"github.com/apex/log"
 	"github.com/caarlos0/ctrlc"
-	"github.com/fatih/color"
 
 	"github.com/blacktop/ipsw/internal/download"
 	"github.com/spf13/cobra"
@@ -125,11 +124,6 @@ var downloadDevCmd = &cobra.Command{
 	SilenceErrors: true,
 	RunE: func(cmd *cobra.Command, args []string) error {
 
-		if viper.GetBool("verbose") {
-			log.SetLevel(log.DebugLevel)
-		}
-		color.NoColor = viper.GetBool("no-color")
-
 		// settings
 		proxy := viper.GetString("download.dev.proxy")
 		insecure := viper.GetBool("download.dev.insecure")
