@@ -33,7 +33,6 @@ import (
 	"github.com/blacktop/go-macho"
 	"github.com/blacktop/go-macho/pkg/fixupchains"
 	"github.com/blacktop/ipsw/pkg/dyld"
-	"github.com/fatih/color"
 	"github.com/pkg/errors"
 	"github.com/spf13/cobra"
 	"github.com/spf13/viper"
@@ -132,11 +131,6 @@ var dyldExtractCmd = &cobra.Command{
 		var p *mpb.Progress
 		var images []*dyld.CacheImage
 
-		if viper.GetBool("verbose") {
-			log.SetLevel(log.DebugLevel)
-		}
-		color.NoColor = viper.GetBool("no-color")
-
 		// flags
 		dumpALL := viper.GetBool("dyld.extract.all")
 		forceExtract := viper.GetBool("dyld.extract.force")
@@ -153,6 +147,8 @@ var dyldExtractCmd = &cobra.Command{
 			return fmt.Errorf("must specify at least one DYLIB to extract")
 		}
 
+		log.Warn("This command is currently experimental and may not work as expected. https://github.com/blacktop/ipsw/issues/467")
+
 		dscPath := filepath.Clean(args[0])
 
 		folder := filepath.Dir(dscPath) // default to folder of shared cache
