@@ -42,10 +42,11 @@ func init() {
 	extractCmd.Flags().BoolP("remote", "r", false, "Extract from URL")
 	extractCmd.Flags().String("proxy", "", "HTTP/HTTPS proxy")
 	extractCmd.Flags().Bool("insecure", false, "do not verify ssl certs")
+	extractCmd.Flags().BoolP("lookup", "l", false, "Lookup decryption keys on theapplewiki.com")
 	extractCmd.Flags().BoolP("kernel", "k", false, "Extract kernelcache")
 	extractCmd.Flags().BoolP("dyld", "d", false, "Extract dyld_shared_cache")
 	extractCmd.Flags().Bool("dtree", false, "Extract DeviceTree")
-	extractCmd.Flags().String("dmg", "", "Extract DMG file (app, sys, fs)")
+	extractCmd.Flags().String("dmg", "", fmt.Sprintf("Extract DMG file (%s)", strings.Join(mount.DmgTypes, ", ")))
 	extractCmd.Flags().Bool("iboot", false, "Extract iBoot")
 	extractCmd.Flags().Bool("sep", false, "Extract sep-firmware")
 	extractCmd.Flags().Bool("sptm", false, "Extract SPTM and TXM Firmwares")
@@ -66,18 +67,21 @@ func init() {
 	})
 	extractCmd.Flags().Bool("driverkit", false, "Extract DriverKit dyld_shared_cache")
 	extractCmd.Flags().String("device", "", "Device to extract kernel for (e.g. iPhone10,6)")
+	extractCmd.Flags().String("ident", "", "Identity Variant to select specific RestoreRamDisk (e.g. 'Erase', 'Upgrade', 'Recovery')")
 	extractCmd.RegisterFlagCompletionFunc("dmg", func(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
 		return []string{
 			"app\tAppOS",
 			"sys\tSystemOS",
 			"fs\tFileSystem",
 			"exc\tExclave",
+			"rdisk\tRestoreRamDisk",
 		}, cobra.ShellCompDirectiveDefault
 	})
 
 	viper.BindPFlag("extract.proxy", extractCmd.Flags().Lookup("proxy"))
 	viper.BindPFlag("extract.insecure", extractCmd.Flags().Lookup("insecure"))
 	viper.BindPFlag("extract.remote", extractCmd.Flags().Lookup("remote"))
+	viper.BindPFlag("extract.lookup", extractCmd.Flags().Lookup("lookup"))
 	viper.BindPFlag("extract.kernel", extractCmd.Flags().Lookup("kernel"))
 	viper.BindPFlag("extract.dyld", extractCmd.Flags().Lookup("dyld"))
 	viper.BindPFlag("extract.dtree", extractCmd.Flags().Lookup("dtree"))
@@ -98,6 +102,7 @@ func init() {
 	viper.BindPFlag("extract.dyld-arch", extractCmd.Flags().Lookup("dyld-arch"))
 	viper.BindPFlag("extract.driverkit", extractCmd.Flags().Lookup("driverkit"))
 	viper.BindPFlag("extract.device", extractCmd.Flags().Lookup("device"))
+	viper.BindPFlag("extract.ident", extractCmd.Flags().Lookup("ident"))
 }
 
 // extractCmd represents the extract command
@@ -187,6 +192,8 @@ var extractCmd = &cobra.Command{
 			Progress:     true,
 			Output:       viper.GetString("extract.output"),
 			JSON:         viper.GetBool("extract.json"),
+			Lookup:       viper.GetBool("extract.lookup"),
+			Ident:        viper.GetString("extract.ident"),
 		}
 
 		if viper.GetBool("extract.remote") {
