@@ -30,7 +30,7 @@ import (
 // backupExtractCmd represents the extract command
 var backupExtractCmd = &cobra.Command{
 	Use:   "extract",
-	Short: "A brief description of your command",
+	Short: "Extract a backup",
 	Long: `A longer description that spans multiple lines and likely contains examples
 and usage of using your command. For example:
 
