@@ -28,10 +28,8 @@ import (
 	"strconv"
 	"strings"
 
-	"github.com/apex/log"
 	"github.com/blacktop/ipsw/internal/utils"
 	"github.com/blacktop/ipsw/pkg/usb/ostrace"
-	"github.com/fatih/color"
 	"github.com/spf13/cobra"
 	"github.com/spf13/viper"
 )
@@ -41,24 +39,20 @@ func init() {
 
 	PsCmd.Flags().StringP("proc", "p", "", "process to get pid for")
 	PsCmd.Flags().BoolP("json", "j", false, "Display processes as JSON")
+	viper.BindPFlag("idev.ps.proc", PsCmd.Flags().Lookup("proc"))
+	viper.BindPFlag("idev.ps.json", PsCmd.Flags().Lookup("json"))
 }
 
 // PsCmd represents the ps command
 var PsCmd = &cobra.Command{
 	Use:           "ps",
 	Short:         "Process list",
-	SilenceUsage:  true,
 	SilenceErrors: true,
 	RunE: func(cmd *cobra.Command, args []string) error {
 
-		if viper.GetBool("verbose") {
-			log.SetLevel(log.DebugLevel)
-		}
-		color.NoColor = viper.GetBool("no-color")
-
-		udid, _ := cmd.Flags().GetString("udid")
-		proc, _ := cmd.Flags().GetString("proc")
-		asJSON, _ := cmd.Flags().GetBool("json")
+		udid := viper.GetString("idev.udid")
+		proc := viper.GetString("idev.ps.proc")
+		asJSON := viper.GetBool("idev.ps.json")
 
 		if len(udid) == 0 {
 			dev, err := utils.PickDevice()
