@@ -26,11 +26,8 @@ package idev
 import (
 	"fmt"
 
-	"github.com/apex/log"
 	"github.com/blacktop/ipsw/pkg/usb/irecv"
-	"github.com/fatih/color"
 	"github.com/spf13/cobra"
-	"github.com/spf13/viper"
 )
 
 func init() {
@@ -42,15 +39,9 @@ var restoreExitCmd = &cobra.Command{
 	Use:           "exit",
 	Short:         "Exit recovery mode",
 	Args:          cobra.NoArgs,
-	SilenceUsage:  true,
 	SilenceErrors: true,
 	RunE: func(cmd *cobra.Command, args []string) error {
 
-		if viper.GetBool("verbose") {
-			log.SetLevel(log.DebugLevel)
-		}
-		color.NoColor = viper.GetBool("no-color")
-
 		cli, err := irecv.NewClient()
 		if err != nil {
 			return fmt.Errorf("failed to connect to irecv: %w", err)
