@@ -19,8 +19,8 @@ import (
 	"os/exec"
 	"path/filepath"
 	"runtime"
-	"slices"
 	"strings"
+	"sync"
 
 	"github.com/apex/log"
 	"github.com/blacktop/lzfse-cgo"
@@ -136,6 +136,16 @@ func decryptCTR(ciphertext, key, iv []byte) ([]byte, error) {
 	return plaintext, nil
 }
 
+// decryptCTRInPlace decrypts ciphertext in-place, modifying the input slice
+func decryptCTRInPlace(data, key, iv []byte) error {
+	block, err := aes.NewCipher(key)
+	if err != nil {
+		return fmt.Errorf("failed to create new AES cipher: %v", err)
+	}
+	cipher.NewCTR(block, iv).XORKeyStream(data, data)
+	return nil
+}
+
 func deriveKey(inkey, salt, info []byte) ([]byte, error) {
 	key := make([]byte, len(inkey))
 	n, err := hkdf.New(sha256.New, inkey, salt, info).Read(key)
@@ -150,26 +160,94 @@ func deriveKey(inkey, salt, info []byte) ([]byte, error) {
 
 func getHMAC(key, data, salt []byte) (HMAC, error) {
 	mac := hmac.New(sha256.New, key)
-	if _, err := mac.Write(slices.Concat(
-		salt,
-		binary.LittleEndian.AppendUint64(
-			data,
-			uint64(len(salt)),
-		),
-	)); err != nil {
-		return HMAC{}, fmt.Errorf("failed to write HMAC: %v", err)
+	// Write salt first
+	if len(salt) > 0 {
+		if _, err := mac.Write(salt); err != nil {
+			return HMAC{}, fmt.Errorf("failed to write salt to HMAC: %v", err)
+		}
+	}
+	// Write data
+	if _, err := mac.Write(data); err != nil {
+		return HMAC{}, fmt.Errorf("failed to write data to HMAC: %v", err)
+	}
+	// Write salt length as uint64
+	var lenBuf [8]byte
+	binary.LittleEndian.PutUint64(lenBuf[:], uint64(len(salt)))
+	if _, err := mac.Write(lenBuf[:]); err != nil {
+		return HMAC{}, fmt.Errorf("failed to write length to HMAC: %v", err)
 	}
 	return HMAC(mac.Sum(nil)), nil
 }
 
+// bufferPool is used to reuse byte slices for segment data to reduce allocations
+type bufferPool struct {
+	pool sync.Pool
+}
+
+func newBufferPool() *bufferPool {
+	return &bufferPool{
+		pool: sync.Pool{
+			New: func() any {
+				// Start with a reasonable default size; will grow as needed
+				b := make([]byte, 0, 1<<20) // 1MB initial capacity
+				return &b
+			},
+		},
+	}
+}
+
+func (p *bufferPool) get(size int) []byte {
+	buf := p.pool.Get().(*[]byte)
+	if cap(*buf) < size {
+		// Need a larger buffer
+		*buf = make([]byte, size)
+	} else {
+		*buf = (*buf)[:size]
+	}
+	return *buf
+}
+
+func (p *bufferPool) put(buf []byte) {
+	// Keep the buffer for reuse
+	b := buf[:0]
+	p.pool.Put(&b)
+}
+
 func decryptClusters(ctx context.Context, r io.ReadSeeker, outfile *os.File, mainKey []byte, clusterMAC HMAC, rootHdr RootHeader) error {
-	eg, _ := errgroup.WithContext(ctx)
+	// Limit concurrent goroutines to prevent resource exhaustion
+	// Use fewer workers to reduce peak memory (each worker holds ~2MB for segment + decomp)
+	maxWorkers := min(runtime.GOMAXPROCS(0), 4)
+
+	// Buffer pool for segment data to reduce allocations
+	segPool := newBufferPool()
+	decompPool := newBufferPool()
 
 	segmentHeaderSize := checksumSize[rootHdr.Checksum] + 8
 	cindex := uint32(0)
 	totalSize := uint64(0)
 
+	// Pre-allocate reusable buffers for cluster-level data
+	encSegmentHdrData := make([]byte, segmentHeaderSize*rootHdr.SegmentsPerCluster)
+	segmentMacData := make([]byte, 32*rootHdr.SegmentsPerCluster)
+	segmentMACs := make([]HMAC, rootHdr.SegmentsPerCluster)
+	segmentHdrs := make([]SegmentHeader, rootHdr.SegmentsPerCluster)
+
+	// Pre-allocate segment key info buffer
+	segKeyInfoBuf := make([]byte, len(SegmentKeyInfo)+4)
+	copy(segKeyInfoBuf, SegmentKeyInfo)
+
 	for {
+		select {
+		case <-ctx.Done():
+			return ctx.Err()
+		default:
+		}
+
+		// Create a new errgroup for each cluster to avoid context reuse issues
+		eg, egCtx := errgroup.WithContext(ctx)
+		eg.SetLimit(maxWorkers)
+		_ = egCtx // used for cancellation propagation via errgroup
+
 		clusterKey, err := deriveKey(mainKey, []byte{},
 			binary.LittleEndian.AppendUint32(
 				[]byte(ClusterKeyInfo),
@@ -188,124 +266,192 @@ func decryptClusters(ctx context.Context, r io.ReadSeeker, outfile *os.File, mai
 		); err != nil {
 			return fmt.Errorf("failed to derive cluster header key: %v", err)
 		}
-		encSegmentHdrData := make([]byte, segmentHeaderSize*rootHdr.SegmentsPerCluster)
-		if _, err := r.Read(encSegmentHdrData); err != nil {
+		if _, err := io.ReadFull(r, encSegmentHdrData); err != nil {
 			return fmt.Errorf("failed to read encrypted segment headers data: %v", err)
 		}
 		var nextClusterMac HMAC
 		if err := binary.Read(r, binary.LittleEndian, &nextClusterMac); err != nil {
 			return fmt.Errorf("failed to read next cluster HMAC: %v", err)
 		}
-		segmentMacData := make([]byte, 32*rootHdr.SegmentsPerCluster)
-		if _, err := r.Read(segmentMacData); err != nil {
+		if _, err := io.ReadFull(r, segmentMacData); err != nil {
 			return fmt.Errorf("failed to read segment HMAC data: %v", err)
 		}
-		shmac, err := getHMAC(clusterHeaderKey.MAC[:], encSegmentHdrData, slices.Concat(nextClusterMac[:], segmentMacData))
+
+		// Build salt for HMAC without allocating (reuse existing slices)
+		hmacSalt := make([]byte, len(nextClusterMac)+len(segmentMacData))
+		copy(hmacSalt, nextClusterMac[:])
+		copy(hmacSalt[len(nextClusterMac):], segmentMacData)
+
+		shmac, err := getHMAC(clusterHeaderKey.MAC[:], encSegmentHdrData, hmacSalt)
 		if err != nil {
 			return fmt.Errorf("failed to get HMAC for encrypted segment headers data: %v", err)
 		}
 		if !hmac.Equal(clusterMAC[:], shmac[:]) {
 			return fmt.Errorf("invalid cluster #%d HMAC: %x; expected %x", cindex, clusterMAC, shmac)
 		}
-		segmentMACs := make([]HMAC, rootHdr.SegmentsPerCluster)
 		if err := binary.Read(bytes.NewReader(segmentMacData), binary.LittleEndian, &segmentMACs); err != nil {
 			return fmt.Errorf("failed to read segment HMACs: %v", err)
 		}
-		segmmentHdrData, err := decryptCTR(encSegmentHdrData, clusterHeaderKey.Key[:], clusterHeaderKey.IV[:])
+		segmentHdrData, err := decryptCTR(encSegmentHdrData, clusterHeaderKey.Key[:], clusterHeaderKey.IV[:])
 		if err != nil {
 			return fmt.Errorf("failed to decrypt segment headers: %v", err)
 		}
-		segmentHdrs := make([]SegmentHeader, rootHdr.SegmentsPerCluster)
-		if err := binary.Read(bytes.NewReader(segmmentHdrData), binary.LittleEndian, segmentHdrs); err != nil {
+		if err := binary.Read(bytes.NewReader(segmentHdrData), binary.LittleEndian, segmentHdrs); err != nil {
 			return fmt.Errorf("failed to read segment headers: %v", err)
 		}
 
-		// decrypt segments
+		// decrypt segments with limited concurrency
+		currentClusterIdx := cindex // capture for goroutines
 		for idx, seg := range segmentHdrs {
 			if seg.DecompressedSize == 0 {
 				continue
 			}
 			totalSize += uint64(seg.DecompressedSize)
-			segmentData := make([]byte, seg.CompressedSize)
-			if _, err = r.Read(segmentData); err != nil {
+
+			// Read segment data (must be done sequentially from the reader)
+			// Get buffer from pool instead of allocating
+			segmentData := segPool.get(int(seg.CompressedSize))
+			if _, err = io.ReadFull(r, segmentData); err != nil {
+				segPool.put(segmentData)
 				return fmt.Errorf("failed to read segment data: %v", err)
 			}
-			decomp := make([]byte, 0, seg.DecompressedSize)
-			func(index int, data []byte, size uint32) {
-				eg.Go(func() error {
-					pos := int64(cindex)*int64(rootHdr.SegmentSize)*int64(rootHdr.SegmentsPerCluster) +
-						int64(index)*int64(rootHdr.SegmentSize)
-					var segmentKey headerKey
-					if err := binary.Read(
-						hkdf.New(sha256.New, clusterKey, []byte{}, binary.LittleEndian.AppendUint32(
-							[]byte(SegmentKeyInfo[:]),
-							uint32(index),
-						)),
-						binary.LittleEndian,
-						&segmentKey,
-					); err != nil {
-						return fmt.Errorf("failed to derive segment key: %v", err)
-					}
-					shmac, err := getHMAC(segmentKey.MAC[:], data, []byte{})
-					if err != nil {
-						return fmt.Errorf("failed to get HMAC for segment header: %v", err)
-					}
-					if !hmac.Equal(segmentMACs[index][:], shmac[:]) {
-						return fmt.Errorf("invalid segment #%d HMAC: %x; expected %x", index, segmentMACs[index], shmac)
-					}
-					decryptedData, err := decryptCTR(data, segmentKey.Key[:], segmentKey.IV[:])
-					if err != nil {
-						return fmt.Errorf("failed to decrypt segment data: %v", err)
-					}
-					if seg.DecompressedSize == seg.CompressedSize { // no compression
-						if _, err := outfile.WriteAt(decryptedData, pos); err != nil {
-							return fmt.Errorf("failed to write uncompressed decrypted data to file: %v", err)
-						}
-					} else {
-						switch rootHdr.Compression {
-						case NONE:
-							decomp = decryptedData
-						case LZBITMAP:
-							lzfse.LzBitMapDecompress(decryptedData, decomp)
-						case LZFSE:
-							decomp = lzfse.DecodeBuffer(decryptedData)
-						case LZMA:
-							lzfse.DecodeLZVNBuffer(decryptedData, decomp)
-						case ZLIB:
-							zr, err := zlib.NewReader(bytes.NewReader(decryptedData))
-							if err != nil {
-								return fmt.Errorf("failed to create zlib reader: %v", err)
-							}
-							decomp, err = io.ReadAll(zr)
-							if err != nil {
-								return fmt.Errorf("failed to read zlib decompressed data: %v", err)
-							}
-						default:
-							// TODO: https://github.com/pierrec/lz4
-							// TODO: https://pkg.go.dev/github.com/ulikunitz/xz/lzma
-							return fmt.Errorf("unsupported compression type: %s", rootHdr.Compression)
-						}
-						switch rootHdr.Checksum {
-						case None:
-						case Sha256:
-							if sha256.Sum256(decomp) != seg.Checksum {
-								return fmt.Errorf("invalid SHA256 checksum for segment %d (cluster %d): expected %x; got %x", index, cindex, seg.Checksum, sha256.Sum256(decomp))
-							}
-						case Murmur:
-							if murmur3.SeedSum64(0xE2236FDC26A5F6D2, decomp) != binary.LittleEndian.Uint64(seg.Checksum[:8]) {
-								return fmt.Errorf("invalid MURMUR checksum for segment %d (cluster %d): expected %x; got %x", index, cindex, binary.LittleEndian.Uint64(seg.Checksum[:8]), murmur3.SeedSum64(0xE2236FDC26A5F6D2, decomp))
-							}
-						default:
-							return fmt.Errorf("unsupported checksum type: %d", rootHdr.Checksum)
-						}
-						/* write decompressed data to file */
-						if _, err := outfile.WriteAt(decomp, pos); err != nil {
-							return fmt.Errorf("failed to write decompressed decrypted data to file: %v", err)
-						}
+
+			// Capture loop variables for goroutine
+			segIdx := idx
+			segHdr := seg
+			segData := segmentData
+			segMAC := segmentMACs[idx]
+			clKey := clusterKey // capture cluster key for this cluster
+
+			eg.Go(func() error {
+				// Ensure we return the buffer to the pool when done
+				defer segPool.put(segData)
+
+				pos := int64(currentClusterIdx)*int64(rootHdr.SegmentSize)*int64(rootHdr.SegmentsPerCluster) +
+					int64(segIdx)*int64(rootHdr.SegmentSize)
+
+				// Derive segment key
+				keyInfo := make([]byte, len(SegmentKeyInfo)+4)
+				copy(keyInfo, SegmentKeyInfo)
+				binary.LittleEndian.PutUint32(keyInfo[len(SegmentKeyInfo):], uint32(segIdx))
+
+				var segmentKey headerKey
+				if err := binary.Read(
+					hkdf.New(sha256.New, clKey, []byte{}, keyInfo),
+					binary.LittleEndian,
+					&segmentKey,
+				); err != nil {
+					return fmt.Errorf("failed to derive segment key: %v", err)
+				}
+
+				// Verify HMAC
+				shmac, err := getHMAC(segmentKey.MAC[:], segData, nil)
+				if err != nil {
+					return fmt.Errorf("failed to get HMAC for segment header: %v", err)
+				}
+				if !hmac.Equal(segMAC[:], shmac[:]) {
+					return fmt.Errorf("invalid segment #%d HMAC: %x; expected %x", segIdx, segMAC, shmac)
+				}
+
+				// Decrypt in-place to avoid allocation
+				if err := decryptCTRInPlace(segData, segmentKey.Key[:], segmentKey.IV[:]); err != nil {
+					return fmt.Errorf("failed to decrypt segment data: %v", err)
+				}
+
+				// Handle uncompressed data
+				if segHdr.DecompressedSize == segHdr.CompressedSize {
+					if _, err := outfile.WriteAt(segData, pos); err != nil {
+						return fmt.Errorf("failed to write uncompressed decrypted data to file: %v", err)
 					}
 					return nil
-				})
-			}(idx, segmentData, seg.DecompressedSize)
+				}
+
+				// Decompress - use pool for buffers where we control allocation
+				var decomp []byte
+				var decompFromPool bool
+				switch rootHdr.Compression {
+				case NONE:
+					decomp = segData
+				case LZBITMAP:
+					decomp = decompPool.get(int(segHdr.DecompressedSize))
+					decompFromPool = true
+					lzfse.LzBitMapDecompress(segData, decomp)
+				case LZFSE:
+					// Use our own decodeLZFSE that takes a pre-allocated buffer
+					decomp = decompPool.get(int(segHdr.DecompressedSize))
+					decompFromPool = true
+					n := decodeLZFSE(segData, decomp)
+					if n == 0 {
+						decompPool.put(decomp)
+						return fmt.Errorf("failed to decompress LZFSE segment %d", segIdx)
+					}
+					decomp = decomp[:n]
+				case LZMA:
+					decomp = decompPool.get(int(segHdr.DecompressedSize))
+					decompFromPool = true
+					lzfse.DecodeLZVNBuffer(segData, decomp)
+				case ZLIB:
+					// Use pool buffer and read into it
+					decomp = decompPool.get(int(segHdr.DecompressedSize))
+					decompFromPool = true
+					zr, err := zlib.NewReader(bytes.NewReader(segData))
+					if err != nil {
+						decompPool.put(decomp)
+						return fmt.Errorf("failed to create zlib reader: %v", err)
+					}
+					n, err := io.ReadFull(zr, decomp)
+					zr.Close()
+					if err != nil && err != io.ErrUnexpectedEOF {
+						decompPool.put(decomp)
+						return fmt.Errorf("failed to read zlib decompressed data: %v", err)
+					}
+					decomp = decomp[:n]
+				default:
+					return fmt.Errorf("unsupported compression type: %s", rootHdr.Compression)
+				}
+
+				// Verify checksum
+				switch rootHdr.Checksum {
+				case None:
+					// no checksum
+				case Sha256:
+					computed := sha256.Sum256(decomp)
+					if computed != segHdr.Checksum {
+						if decompFromPool {
+							decompPool.put(decomp)
+						}
+						return fmt.Errorf("invalid SHA256 checksum for segment %d (cluster %d): expected %x; got %x", segIdx, currentClusterIdx, segHdr.Checksum, computed)
+					}
+				case Murmur:
+					computed := murmur3.SeedSum64(0xE2236FDC26A5F6D2, decomp)
+					expected := binary.LittleEndian.Uint64(segHdr.Checksum[:8])
+					if computed != expected {
+						if decompFromPool {
+							decompPool.put(decomp)
+						}
+						return fmt.Errorf("invalid MURMUR checksum for segment %d (cluster %d): expected %x; got %x", segIdx, currentClusterIdx, expected, computed)
+					}
+				default:
+					if decompFromPool {
+						decompPool.put(decomp)
+					}
+					return fmt.Errorf("unsupported checksum type: %d", rootHdr.Checksum)
+				}
+
+				// Write decompressed data to file
+				if _, err := outfile.WriteAt(decomp, pos); err != nil {
+					if decompFromPool {
+						decompPool.put(decomp)
+					}
+					return fmt.Errorf("failed to write decompressed decrypted data to file: %v", err)
+				}
+
+				// Return decompression buffer to pool
+				if decompFromPool {
+					decompPool.put(decomp)
+				}
+				return nil
+			})
 		}
 
 		if err := eg.Wait(); err != nil {
@@ -407,8 +553,12 @@ func decrypt(in, out string, symmetricKey []byte) (string, error) {
 	); err != nil {
 		return "", fmt.Errorf("failed to derive root header key: %v", err)
 	}
+	// Build HMAC salt without allocation
+	hmacSalt := make([]byte, len(encRootHdr.ClusterHmac)+len(authData))
+	copy(hmacSalt, encRootHdr.ClusterHmac[:])
+	copy(hmacSalt[len(encRootHdr.ClusterHmac):], authData)
 	// verify root header HMAC
-	rhmac, err := getHMAC(rootHdrKey.MAC[:], encRootHdr.Data[:], slices.Concat(encRootHdr.ClusterHmac[:], authData[:]))
+	rhmac, err := getHMAC(rootHdrKey.MAC[:], encRootHdr.Data[:], hmacSalt)
 	if err != nil {
 		return "", fmt.Errorf("failed to get encrypted root header HMAC: %v", err)
 	}
@@ -431,7 +581,7 @@ func decrypt(in, out string, symmetricKey []byte) (string, error) {
 	defer of.Close()
 
 	if err := decryptClusters(context.Background(), f, of, mainKey, encRootHdr.ClusterHmac, rootHdr); err != nil {
-		log.WithError(err).Error("failed to decrypt cluster")
+		return "", fmt.Errorf("failed to decrypt clusters: %v", err)
 	}
 
 	finfo, err := of.Stat()
@@ -488,11 +638,18 @@ func Decrypt(c *DecryptConfig) (string, error) {
 		return decrypt(c.Input, filepath.Join(c.Output, filepath.Base(strings.TrimSuffix(c.Input, filepath.Ext(c.Input)))), c.symEncKey)
 	}
 	// use 'aea' binary (as is the fastest way to decrypt AEA on macOS)
-	return aea(
+	out, err := aea(
 		c.Input,
 		filepath.Join(c.Output, filepath.Base(strings.TrimSuffix(c.Input, filepath.Ext(c.Input)))),
 		c.B64SymKey,
 	)
+	if err != nil {
+		// fallback to pure Go implementation if system binary fails
+		// (can happen due to resource exhaustion or other transient errors)
+		log.WithError(err).Warn("System 'aea' binary failed, falling back to pure Go implementation")
+		return decrypt(c.Input, filepath.Join(c.Output, filepath.Base(strings.TrimSuffix(c.Input, filepath.Ext(c.Input)))), c.symEncKey)
+	}
+	return out, nil
 }
 
 func aea(in, out, key string) (string, error) {
